@@ -3,9 +3,10 @@
 #'   stats
 #'
 #' @importFrom cluster silhouette
+#' @importFrom coda as.mcmc.list
 #' @importFrom dendextend set %>%
-#' @importFrom fdrtool rhalfnorm
 #' @importFrom MASS fractions
+#' @importFrom Matrix bdiag
 #' @importFrom gemtc mtc.network mtc.data.studyrow mtc.nodesplit.comparisons
 #' @importFrom ggfittext geom_fit_text
 #' @importFrom ggpubr ggarrange
@@ -14,6 +15,7 @@
 #' @importFrom heatmaply heatmaply
 #' @importFrom igraph count_components distances E layout_in_circle make_graph plot.igraph V
 #' @importFrom knitr kable
+#' @importFrom coda as.mcmc traceplot densplot
 #' @importFrom reshape2 melt
 #' @importFrom R2jags jags autojags
 #' @importFrom scales hue_pal rescale percent
@@ -95,5 +97,6 @@ utils::globalVariables(c("active",
 
 #Sys.setenv(`_R_S3_METHOD_REGISTRATION_NOTE_OVERWRITES_` = "false")
 Sys.setenv(JAGS_HOME = "C:/Program Files/JAGS/JAGS-4.3.1")
-Sys.setenv(JAGS_ROOT = "C:/Program Files/JAGS/JAGS-4.3.1")
+#Sys.setenv(JAGS_ROOT = "C:/Program Files/JAGS/JAGS-4.3.1")
+Sys.setenv('_R_CHECK_SYSTEM_CLOCK_' = 0)
 
