@@ -80,7 +80,10 @@
 #' \emph{Stat Med} 2015;\bold{34}(12):2062--80. doi: 10.1002/sim.6475
 #'
 #' @export
-prepare_model <- function(measure, model, covar_assumption, assumption) {
+prepare_model <- function(measure,
+                          model,
+                          covar_assumption,
+                          assumption) {
 
   stringcode <- "model {
                     for (i in 1:ns) {\n"
@@ -163,7 +166,7 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
     paste(stringcode, "delta.star[i, k] <- delta[i, k] + Beta[i, k]
                        delta[i, k] ~ dnorm(md[i, k], precd[i, k])
                        md[i, k] <- (d[t[i, k]]*indic[i, k] - d[t[i, 1]]*indic[i, 1]) + sw[i, k]
-                       precd[i, k] <- 2*prec*(k - 1)/k
+                       precd[i, k] <- (2 * prec * (k - 1)) / k
                        w[i, k] <- delta[i, k] - (d[t[i, k]]*indic[i, k] - d[t[i, 1]]*indic[i, 1])
                        sw[i, k] <- sum(w[i, 1:(k - 1)])/(k - 1)
                        }}\n")
@@ -194,13 +197,14 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                                    d.n[ref] <- 0
                                    for (t in 1:(ref - 1)) {
                                      d[t] ~ dnorm(0, 0.0001)
-                                     d.n[t] <- d[t]*equals(min(t, ref), ref) + d[t]*(-1)*equals(min(t, ref), t)
+                                     d.n[t] <- d[t]*equals(min(t, ref), ref) + d[t]*(-1)*equals(min(t, ref), t) + beta.n[t] * cov_value
                                    }
                                    for (t in (ref + 1):nt) {
                                      d[t] ~ dnorm(0, 0.0001)
-                                     d.n[t] <- d[t]*equals(min(t, ref), ref) + d[t]*(-1)*equals(min(t, ref), t)
+                                     d.n[t] <- d[t]*equals(min(t, ref), ref) + d[t]*(-1)*equals(min(t, ref), t) + beta.n[t] * cov_value
                                    }\n")
 
+
   stringcode <- if (is.element(measure, c("OR", "RR", "RD"))) {
     paste(stringcode, "mean_logit_base_event <- ref_base[1]
                        prec_logit_base_event <- ref_base[2]*(1 - equals(ref_base[1], ref_base[2])) + equals(ref_base[1], ref_base[2])
@@ -208,7 +212,7 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                        base_risk_logit <- logit_base_risk*(1 - equals(ref_base[1], ref_base[2])) + ref_base[1]*equals(ref_base[1], ref_base[2])
                        base_risk <- exp(base_risk_logit)/(1 + exp(base_risk_logit))
                        for (t in 1:nt) {
-                         logit(abs_risk[t]) <- base_risk_logit + d[t]
+                         logit(abs_risk[t]) <- base_risk_logit + d[t] + beta.t[t] * cov_value
                        }\n")
   } else {
     paste(stringcode, " ")
@@ -216,13 +220,16 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
 
   stringcode <- if (covar_assumption == "exchangeable") {
     paste(stringcode, "beta[ref] <- 0
+                       beta.t[ref] <- 0
                        beta.n[ref] <- 0
                        for (t in 1:(ref - 1)) {
                          beta[t] ~ dnorm(mean.B, prec.B)
+                         beta.t[t] <- beta[t]
                          beta.n[t] <- beta[t]*equals(min(t, ref), ref) + beta[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
                          beta[t] ~ dnorm(mean.B, prec.B)
+                         beta.t[t] <- beta[t]
                          beta.n[t] <- beta[t]*equals(min(t, ref), ref) + beta[t]*(-1)*equals(min(t, ref), t)
                        }
                        mean.B ~ dnorm(0, .0001)
@@ -234,13 +241,16 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                        }}\n")
   } else if (covar_assumption == "independent") {
     paste(stringcode, "beta[ref] <- 0
+                       beta.t[ref] <- 0
                        beta.n[ref] <- 0
                        for (t in 1:(ref - 1)) {
                          beta[t] ~ dnorm(0, 0.0001)
+                         beta.t[t] <- beta[t]
                          beta.n[t] <- beta[t]*equals(min(t, ref), ref) + beta[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
                          beta[t] ~ dnorm(0, 0.0001)
+                         beta.t[t] <- beta[t]
                          beta.n[t] <- beta[t]*equals(min(t, ref), ref) + beta[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (c in 1:(nt - 1)) {
@@ -249,11 +259,14 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                        }}\n")
   } else if (covar_assumption == "common") {
     paste(stringcode, "beta ~ dnorm(0, 0.0001)
+                       beta.t[ref] <- 0
                        beta.n[ref] <- 0
                        for (t in 1:(ref - 1)) {
+                         beta.t[t] <- beta
                          beta.n[t] <- beta*equals(min(t, ref), ref) + beta*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
+                         beta.t[t] <- beta
                          beta.n[t] <- beta*equals(min(t, ref), ref) + beta*(-1)*equals(min(t, ref), t)
                        }
                        for (c in 1:(nt - 1)) {
@@ -390,11 +403,11 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                        }}\n")
   } else if (model == "RE" & measure == "RR") {
     paste(stringcode, "for (t in 1:(ref - 1)) {
-                         EM.ref.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref[t] <- EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
-                         EM.ref.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref[t] <- EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (c in 1:(nt - 1)) {
@@ -406,13 +419,13 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                        }}\n")
   } else if (model == "RE" & measure == "RD") {
     paste(stringcode, "for (t in 1:(ref - 1)) {
-                         EM.ref.RR.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.RR.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref.RR[t] <- EM.ref.RR.n[t]*equals(min(t, ref), ref) + EM.ref.RR.n[t]*(-1)*equals(min(t, ref), t)
                          EM.ref.n[t] <- (exp(EM.ref.RR.n[t]) - 1)*base_risk
                          EM.ref[t] <- EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
-                         EM.ref.RR.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.RR.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref.RR[t] <- EM.ref.RR.n[t]*equals(min(t, ref), ref) + EM.ref.RR.n[t]*(-1)*equals(min(t, ref), t)
                          EM.ref.n[t] <- (exp(EM.ref.RR.n[t]) - 1)*base_risk
                          EM.ref[t] <-  EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
@@ -428,11 +441,11 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                        }}\n")
   } else if (model == "FE" & measure == "RR") {
     paste(stringcode, "for (t in 1:(ref - 1)) {
-                         EM.ref.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref[t] <- EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
-                         EM.ref.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref[t] <- EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
                        for (c in 1:(nt - 1)) {
                          for (k in (c + 1):nt) {
@@ -441,13 +454,13 @@ prepare_model <- function(measure, model, covar_assumption, assumption) {
                         }}\n")
   } else if (model == "FE" & measure == "RD") {
     paste(stringcode, "for (t in 1:(ref - 1)) {
-                         EM.ref.RR.n <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.RR.n <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref.RR[t] <- EM.ref.RR.n[t]*equals(min(t, ref), ref) + EM.ref.RR.n[t]*(-1)*equals(min(t, ref), t)
                          EM.ref.n[t] <- (exp(EM.ref.RR.n[t] - 1))*base_risk
                          EM.ref[t] <-  EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
                        }
                        for (t in (ref + 1):nt) {
-                         EM.ref.RR.n[t] <- d[t] - log(1 - (1 - exp(d[t]))*base_risk)
+                         EM.ref.RR.n[t] <- (d[t] + beta.t[t] * cov_value) - log(1 - (1 - exp(d[t] + beta.t[t] * cov_value))*base_risk)
                          EM.ref.RR[t] <- EM.ref.RR.n[t]*equals(min(t, ref), ref) + EM.ref.RR.n[t]*(-1)*(equals(min(t, ref), t)
                          EM.ref.n[t] <- (exp(EM.ref.RR.n[t]) - 1)*base_risk
                          EM.ref[t] <-  EM.ref.n[t]*equals(min(t, ref), ref) + EM.ref.n[t]*(-1)*equals(min(t, ref), t)
