@@ -13,6 +13,7 @@
 #'   intervention-by-covariate interaction, as described in
 #'   Cooper et al. (2009). Set \code{covar_assumption} equal to
 #'   \code{"exchangeable"}, \code{"independent"}, or \code{"common"}.
+#' @param cov_value Numeric for the covariate value of interest.
 #' @param n_chains Positive integer specifying the number of chains for the
 #'   MCMC sampling; an argument of the \code{\link[R2jags:jags]{jags}} function
 #'   of the R-package \href{https://CRAN.R-project.org/package=R2jags}{R2jags}.
@@ -161,6 +162,7 @@
 #' run_metareg(full = res,
 #'             covariate = pub_year,
 #'             covar_assumption = "exchangeable",
+#'             cov_value = 2007,
 #'             n_chains = 3,
 #'             n_iter = 1000,
 #'             n_burnin = 100,
@@ -171,6 +173,7 @@
 run_metareg <- function(full,
                         covariate,
                         covar_assumption,
+                        cov_value,
                         n_chains,
                         n_iter,
                         n_burnin,
@@ -213,14 +216,24 @@ run_metareg <- function(full,
   } else {
     covar_assumption
   }
-  ref_base <- if (is.element(measure, c("OR", "RR", "RD")) &
-                  missing(base_risk)) {
-    base_risk <-
-      describe_network(data = data,
-                       drug_names = 1:item$nt,
-                       measure = measure)$table_interventions[ref, 7]/100
-    rep(log(base_risk / (1 - base_risk)), 2)
-  } else if (is.element(measure, c("OR", "RR", "RD"))) {
+  cov_val <- if (missing(cov_value)) {
+    stop("The argument 'cov_value' needs to be defined.", call. = FALSE)
+  } else if (length(unique(covariate)) < 3) {
+    cov_value
+  } else if (length(unique(covariate)) > 2) {
+    cov_value - mean(covariate)
+  }
+  if (length(unique(covariate)) < 3 &
+      !is.element(cov_value, covariate)) {
+    aa <- "The argument 'cov_value' is out of the value"
+    stop(paste(aa, "range of the analysed covariate."), call. = FALSE)
+  } else if (length(unique(covariate)) > 2 &
+             (cov_value < min(covariate) |
+              cov_value > max(covariate))) {
+    aa <- "The argument 'cov_value' is out of the value"
+    stop(paste(aa, "range of the analysed covariate."), call. = FALSE)
+  }
+  ref_base <- if (is.element(measure, c("OR", "RR", "RD"))) {
     baseline_model(base_risk,
                    n_chains,
                    n_iter,
@@ -274,7 +287,9 @@ run_metareg <- function(full,
                    "ref" = ref,
                    "I" = item$I,
                    "indic" = indic,
-                   "D" = D)
+                   "D" = D,
+                   "cov_value" = cov_val,
+                   "wgt.value" = rep(1, item$ns))
 
   data_jag <- if (!is.element(measure, c("OR", "RR", "RD"))) {
     append(data_jag, list("y.o" = item$y0,
@@ -348,6 +363,7 @@ run_metareg <- function(full,
 
   # Run the Bayesian analysis
   message("Running the model ...")
+  suppressWarnings({
   jagsfit0 <- jags(data = data_jag,
                    inits = inits,
                    parameters.to.save = param_jags,
@@ -363,70 +379,54 @@ run_metareg <- function(full,
   # Update until convergence is necessary
   message("... Updating the model until convergence")
   jagsfit <- autojags(jagsfit0, n.iter = n_iter, n.thin = n_thin, n.update = 2)
+  })
 
   # Turn R2jags object into a data-frame
   get_results <- as.data.frame(t(jagsfit$BUGSoutput$summary))
 
   # Effect size of all unique pairwise comparisons
-  #EM <- t(get_results %>% dplyr::select(starts_with("EM[")))
   EM <- t(get_results)[startsWith(rownames(t(get_results)), "EM["), ]
 
   # Predictive effects of all unique pairwise comparisons
-  #EM_pred <- t(get_results %>% dplyr::select(starts_with("EM.pred[")))
   EM_pred <- t(get_results)[startsWith(rownames(t(get_results)), "EM.pred["), ]
 
   # Unique absolute risks for all interventions (only binary data)
-  #abs_risk <- t(get_results %>% dplyr::select(starts_with("abs_risk[")))
   abs_risk <-
     t(get_results)[startsWith(rownames(t(get_results)), "abs_risk["), ]
 
   # Between-trial standard deviation
-  #tau <- t(get_results %>% dplyr::select(starts_with("tau")))
   tau <- t(get_results)[startsWith(rownames(t(get_results)), "tau"), ]
 
   # Regression coefficient for all comparisons with the reference intervention
-  #beta <- t(get_results %>% dplyr::select(starts_with("beta[") |
-  #                                         starts_with("beta")))
   beta <-
     t(get_results)[startsWith(rownames(t(get_results)), "beta[") |
                      startsWith(rownames(t(get_results)), "beta"), ]
 
   # Regression coefficient for all unique pairwise comparisons
   # (not applicable for 'common' covar_assumption)
-  #beta_all <- t(get_results %>% dplyr::select(starts_with("beta.all[")))
   beta_all <-
     t(get_results)[startsWith(rownames(t(get_results)), "beta.all["), ]
 
   # SUrface under the Cumulative RAnking curve values
-  #SUCRA <- t(get_results %>% dplyr::select(starts_with("SUCRA")))
   SUCRA <- t(get_results)[startsWith(rownames(t(get_results)), "SUCRA"), ]
 
   # Within-trial effects size
-  #delta <- t(get_results %>% dplyr::select(starts_with("delta") &
-  #                                           !ends_with(",1]")))
   delta <- t(get_results)[startsWith(rownames(t(get_results)), "delta") &
                             !endsWith(rownames(t(get_results)), ",1]"), ]
 
   # Ranking probability of each intervention for every rank
-  #effectiveness <- t(get_results %>% dplyr::select(
-  #  starts_with("effectiveness")))
   effectiveness <-
     t(get_results)[startsWith(rownames(t(get_results)), "effectiveness"), ]
 
   # Estimated missingness parameter
   phi <- if (min(na.omit(unlist(item$I))) == 1 &
              max(na.omit(unlist(item$I))) == 1) {
-    #t(get_results %>% dplyr::select(starts_with("phi") |
-    #                                  starts_with("mean.phi") |
-    #                                  starts_with("mean.phi[") |
-    #                                  starts_with("phi[")))
     t(get_results)[startsWith(rownames(t(get_results)), "phi") |
                      startsWith(rownames(t(get_results)), "mean.phi") |
                      startsWith(rownames(t(get_results)), "mean.phi[") |
                      startsWith(rownames(t(get_results)), "phi["), ]
   } else if (min(na.omit(unlist(item$I))) == 0 &
              max(na.omit(unlist(item$I))) == 1) {
-    #t(get_results %>% dplyr::select(starts_with("phi[")))
     t(get_results)[startsWith(rownames(t(get_results)), "phi["), ]
   } else if (min(na.omit(unlist(item$I))) == 0 &
              max(na.omit(unlist(item$I))) == 0) {
@@ -434,11 +434,9 @@ run_metareg <- function(full,
   }
 
   # Trial-arm deviance contribution for observed outcome
-  #dev_o <- t(get_results %>% dplyr::select(starts_with("dev.o")))
   dev_o <- t(get_results)[startsWith(rownames(t(get_results)), "dev.o"), ]
 
   # Fitted/predicted outcome
-  #hat_par <- t(get_results %>% dplyr::select(starts_with("hat.par")))
   hat_par <- t(get_results)[startsWith(rownames(t(get_results)), "hat.par"), ]
 
   # Total residual deviance
@@ -521,6 +519,7 @@ run_metareg <- function(full,
                        assumption = assumption,
                        covariate = covariate,
                        covar_assumption = covar_assumption,
+                       cov_value = cov_value,
                        jagsfit = jagsfit,
                        data = data,
                        n_chains = n_chains,
@@ -530,7 +529,7 @@ run_metareg <- function(full,
                        abs_risk = abs_risk)
     nma_results <- append(ma_results, list(SUCRA = SUCRA,
                                            effectiveness = effectiveness,
-                                           D = full$D))
+                                           D = D))
   } else if (model == "FE") {
     ma_results <- list(EM = EM,
                        beta_all = beta_all,
@@ -545,6 +544,7 @@ run_metareg <- function(full,
                        assumption = assumption,
                        covariate = covariate,
                        covar_assumption = covar_assumption,
+                       cov_value = cov_value,
                        jagsfit = jagsfit,
                        data = data,
                        n_chains = n_chains,
@@ -554,7 +554,7 @@ run_metareg <- function(full,
                        abs_risk = abs_risk)
     nma_results <- append(ma_results, list(SUCRA = SUCRA,
                                            effectiveness = effectiveness,
-                                           D = full$D))
+                                           D = D))
   }
 
   class(ma_results) <- class(nma_results) <- "run_metareg"
