@@ -98,7 +98,7 @@
 #'    \strong{n} \tab The number of randomised participants in each arm.\cr
 #'   }
 #'
-#'   For a binary outcome, the columns of the data-frame in the argument
+#'  For a binary outcome, the columns of the data-frame in the argument
 #'   \code{data} refer to the following elements:
 #'   \tabular{ll}{
 #'    \strong{t} \tab An intervention identifier in each arm.\cr
@@ -314,8 +314,7 @@
 #'
 #' @seealso \code{\link[R2jags:autojags]{autojags}},
 #'   \code{\link{baseline_model}}, \code{\link{data_preparation}},
-#'   \code{\link{heterogeneity_param_prior}},
-#'   \code{\link[R2jags:jags]{jags}},
+#'   \code{\link{heterogeneity_param_prior}}, \code{\link[R2jags:jags]{jags}},
 #'   \code{\link{missingness_param_prior}}, \code{\link{prepare_model}}
 #'
 #' @references
@@ -496,9 +495,6 @@ run_model <- function(data,
       aggregate(na.omit(unlist(item$r)) /
                   (na.omit(unlist(item$N)) - na.omit(unlist(item$m))),
                 list(na.omit(unlist(item$t))), median)[ref, 2]
-      #describe_network(data = data,
-      #                 drug_names = 1:item$nt,
-      #                 measure = measure)$table_interventions[ref, 7]/100
     rep(log(base_risk / (1 - base_risk)), 2)
   } else if (is.element(measure, c("OR", "RR", "RD"))) {
     baseline_model(base_risk,
@@ -568,7 +564,11 @@ run_model <- function(data,
                    "ref" = ref,
                    "I" = item$I,
                    "indic" = indic,
-                   "D" = D)
+                   "D" = D,
+                   "cov_value" = 0,
+                   "beta.n" = rep(0, item$nt),
+                   "beta.t" = rep(0, item$nt),
+                   "beta" = rep(0, item$nt))
 
   data_jag <- if (is.element(measure, c("MD", "SMD", "ROM"))) {
     append(data_jag, list("y.o" = item$y0,
@@ -633,6 +633,7 @@ run_model <- function(data,
 
   # Run the Bayesian analysis
   message("Running the model ...")
+  suppressWarnings({
   jagsfit0 <- jags(data = data_jag,
                    inits = inits,
                    parameters.to.save = param_jags,
@@ -650,66 +651,51 @@ run_model <- function(data,
   # Update until convergence is necessary
   message("... Updating the model until convergence")
   jagsfit <- autojags(jagsfit0, n.iter = n_iter, n.thin = n_thin, n.update = 2)
+  })
 
   # Turn R2jags object into a data-frame
   get_results <- as.data.frame(t(jagsfit$BUGSoutput$summary))
 
   # Effect size of all unique pairwise comparisons
-  #EM <- t(get_results %>% dplyr::select(starts_with("EM[")))
   EM <- t(get_results)[startsWith(rownames(t(get_results)), "EM["), ]
 
   # Predictive effects of all unique pairwise comparisons
-  #EM_pred <- t(get_results %>% dplyr::select(starts_with("EM.pred[")))
   EM_pred <- t(get_results)[startsWith(rownames(t(get_results)), "EM.pred["), ]
 
   # Unique absolute risks for all interventions (only binary data)
-  #abs_risk <- t(get_results %>% dplyr::select(starts_with("abs_risk[")))
   abs_risk <- t(get_results)[startsWith(rownames(t(get_results)), "abs_risk["),]
 
   # Estimated og odds ratio of all unique pairwise comparisons
   # (when RR and RD have been selected as effect measures)
-  #EM_LOR <- t(get_results %>% dplyr::select(starts_with("EM.LOR[")))
   EM_LOR <- t(get_results)[startsWith(rownames(t(get_results)), "EM.LOR["), ]
 
   # Predicted log odds ratio of all unique pairwise comparisons
   # (when RR and RD have been selected as effect measures)
-  #EM_pred_LOR <- t(get_results %>% dplyr::select(starts_with("EM.pred.LOR[")))
   EM_pred_LOR <-
     t(get_results)[startsWith(rownames(t(get_results)), "EM.pred.LOR["), ]
 
   # Between-trial standard deviation
-  #tau <- t(get_results %>% dplyr::select(starts_with("tau")))
   tau <- t(get_results)[startsWith(rownames(t(get_results)), "tau"), ]
 
   # SUrface under the Cumulative RAnking curve values
-  #SUCRA <- t(get_results %>% dplyr::select(starts_with("SUCRA[")))
   SUCRA <- t(get_results)[startsWith(rownames(t(get_results)), "SUCRA["), ]
 
   # SUrface under the Cumulative RAnking curve values
   # (when RR and RD have been selected as effect measures)
-  #SUCRA_LOR <- t(get_results %>% dplyr::select(starts_with("SUCRA.LOR[")))
   SUCRA_LOR <-
     t(get_results)[startsWith(rownames(t(get_results)), "SUCRA.LOR["), ]
 
   # Within-trial effects size
-  #delta <- t(get_results %>% dplyr::select(starts_with("delta") &
-  #                                           !ends_with(",1]")))
   delta <- t(get_results)[startsWith(rownames(t(get_results)), "delta") &
                             !endsWith(rownames(t(get_results)), ",1]"), ]
 
   # Ranking probability of each intervention for every rank
-  #effectiveness <- t(get_results %>% dplyr::select(
-  #  starts_with("effectiveness")))
   effectiveness <-
     t(get_results)[startsWith(rownames(t(get_results)), "effectiveness"), ]
 
   # Estimated missingness parameter
   phi <- if (min(na.omit(unlist(item$I))) == 1 &
              max(na.omit(unlist(item$I))) == 1) {
-    #t(get_results %>% dplyr::select(starts_with("phi") |
-    #                                  starts_with("mean.phi") |
-    #                                  starts_with("mean.phi[") |
-    #                                  starts_with("phi[")))
     t(get_results)[startsWith(rownames(t(get_results)), "phi") |
                      startsWith(rownames(t(get_results)), "mean.phi") |
                      startsWith(rownames(t(get_results)), "mean.phi[") |
@@ -717,18 +703,15 @@ run_model <- function(data,
   } else if (min(na.omit(unlist(item$I))) == 0 &
              max(na.omit(unlist(item$I))) == 1) {
     t(get_results)[startsWith(rownames(t(get_results)), "phi["), ]
-    #t(get_results %>% dplyr::select(starts_with("phi[")))
   } else if (min(na.omit(unlist(item$I))) == 0 &
              max(na.omit(unlist(item$I))) == 0) {
     NULL
   }
 
   # Trial-arm deviance contribution for observed outcome
-  #dev_o <- t(get_results %>% dplyr::select(starts_with("dev.o")))
   dev_o <- t(get_results)[startsWith(rownames(t(get_results)), "dev.o"), ]
 
   # Fitted/predicted outcome
-  #hat_par <- t(get_results %>% dplyr::select(starts_with("hat.par")))
   hat_par <- t(get_results)[startsWith(rownames(t(get_results)), "hat.par"), ]
 
   # Total residual deviance
