@@ -52,10 +52,16 @@
 #'   random-effects pairwise meta-analysis:
 #'   \item{EM}{The estimated summary effect measure (according to the
 #'    argument \code{measure} defined in \code{\link{run_model}}).}
+#'   \item{EM_pred}{The predicted summary effect measure (according to the
+#'    argument \code{measure} defined in \code{\link{run_model}}). This element
+#'    does not appear in the case of a fixed-effect meta-analysis.}
 #'   \item{EM_LOR}{The estimated summary odd ratio in the logarithmic scale when
 #'   \code{measure = "RR"} or \code{measure = "RD"}.}
+#'   \item{EM_LOR_pred}{The predicted summary odd ratio in the logarithmic scale
+#'    when \code{measure = "RR"} or \code{measure = "RD"}. This element does
+#'    not appear in the case of a fixed-effect meta-analysis.}
 #'   \item{tau}{The between-trial standard deviation. This element does
-#'    not appear in the case of a fixed-effect pairwise meta-analysis.}
+#'    not appear in the case of a fixed-effect meta-analysis.}
 #'
 #'   In a random-effects network meta-analysis, \code{EM} refer to all possible
 #'   pairwise comparisons of interventions in the network. Furthermore,
@@ -257,14 +263,7 @@ run_sensitivity <- function(full,
   } else {
     var_misspar
   }
-  ref_base <- if (is.element(measure, c("OR", "RR", "RD")) &
-                  missing(base_risk)) {
-    base_risk <-
-      describe_network(data = data,
-                       drug_names = 1:item$nt,
-                       measure = measure)$table_interventions[ref, 7]/100
-    rep(log(base_risk / (1 - base_risk)), 2)
-  } else if (is.element(measure, c("OR", "RR", "RD"))) {
+  ref_base <- if (is.element(measure, c("OR", "RR", "RD"))) {
     baseline_model(base_risk,
                    n_chains,
                    n_iter,
@@ -318,13 +317,13 @@ run_sensitivity <- function(full,
 
   ## Parameters to save
   param_jags <- if (model == "RE") {
-    c("EM", "tau")
+    c("EM", "EM.pred", "tau")
   } else {
     c("EM")
   }
 
   param_jags <- if (is.element(measure, c("RR", "RD"))) {
-    append(param_jags, "EM.LOR")
+    append(param_jags, "EM.LOR", "EM.LOR.pred")
   } else {
     param_jags
   }
@@ -342,7 +341,12 @@ run_sensitivity <- function(full,
                           "I" = item$I,
                           "meand.phi" = mean_misspar[i, ],
                           "precd.phi" = 1 / var_misspar,
-                          "D" = D)
+                          "D" = D,
+                          "cov_value" = 0,
+                          "beta.n" = rep(0, item$nt),
+                          "beta.t" = rep(0, item$nt),
+                          "beta" = rep(0, item$nt),
+                          "wgt.value" = rep(1, item$ns))
 
     if (is.element(measure, c("MD", "SMD", "ROM"))) {
       data_jag[[i]] <- append(data_jag[[i]],
@@ -360,6 +364,7 @@ run_sensitivity <- function(full,
     }
 
     message(paste(i, "out of", length(mean_misspar[, 1]), "total scenarios"))
+    suppressWarnings({
     jagsfit0[[i]] <- jags(data = data_jag[[i]],
                           inits = inits,
                           parameters.to.save = param_jags,
@@ -379,6 +384,7 @@ run_sensitivity <- function(full,
                              n.iter = n_iter,
                              n.thin = n_thin,
                              n.update = 2)
+    })
   }
 
   # Obtain the posterior distribution of the necessary model paramters
@@ -387,37 +393,33 @@ run_sensitivity <- function(full,
     get_results[[i]] <- as.data.frame(t(jagsfit[[i]]$BUGSoutput$summary))
   }
 
-  #EM <- do.call(rbind,
-  #              lapply(
-  #                seq_len(length(mean_misspar[, 1])),
-  #                function(i) t(get_results[[i]] %>%
-  #                                dplyr::select(starts_with("EM[")))))
+
   EM <- do.call(rbind,
                 lapply(
                   seq_len(length(mean_misspar[, 1])),
                   function(i) t(get_results[[i]])[
                     startsWith(rownames(t(get_results[[i]])), "EM["), ]))
+  EM_pred <- do.call(rbind,
+                     lapply(seq_len(length(mean_misspar[, 1])),
+                            function(i) t(get_results[[i]])[
+                              startsWith(rownames(t(get_results[[i]])),
+                                         "EM.pred["), ]))
 
   if (is.element(measure, c("RR", "RD"))) {
-    #EM_LOR <- do.call(rbind,
-    #                  lapply(
-    #                    seq_len(length(mean_misspar[, 1])),
-    #                    function(i) t(get_results[[i]] %>%
-    #                                    dplyr::select(starts_with("EM.LOR[")))))
     EM_LOR <- do.call(rbind,
                       lapply(
                         seq_len(length(mean_misspar[, 1])),
                         function(i) t(get_results[[i]])[
                           startsWith(rownames(t(get_results[[i]])),
                                      "EM.LOR["), ]))
+    EM_LOR_pred <- do.call(rbind,
+                           lapply(seq_len(length(mean_misspar[, 1])),
+                                  function(i) t(get_results[[i]])[
+                                    startsWith(rownames(t(get_results[[i]])),
+                                               "EM.LOR.pred["), ]))
   }
 
   if (model == "RE") {
-    #tau <- do.call(rbind,
-    #              lapply(
-    #                seq_len(length(mean_misspar[, 1])),
-    #                function(i) t(get_results[[i]] %>%
-    #                                dplyr::select(starts_with("tau")))))
     tau <- do.call(rbind,
                    lapply(
                      seq_len(length(mean_misspar[, 1])),
@@ -428,6 +430,7 @@ run_sensitivity <- function(full,
   # Return results
   results <- if (model == "RE" & !is.element(measure, c("RR", "RD"))) {
     list(EM = EM,
+         EM_pred = EM_pred,
          tau = tau,
          measure = measure,
          model = model,
@@ -451,6 +454,8 @@ run_sensitivity <- function(full,
   } else if (model == "RE" & is.element(measure, c("RR", "RD"))) {
     list(EM = EM,
          EM_LOR = EM_LOR,
+         EM_pred = EM_pred,
+         EM_LOR_pred = EM_LOR_pred,
          tau = tau,
          measure = measure,
          model = model,
